@@ -17,7 +17,7 @@
 // along with GNU ccAudio2.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <ucommon/ucommon.h>
-#include <config.h>
+#include <ccaudio2-config.h>
 #include <math.h>
 #include <ctype.h>
 #ifdef  HAVE_ENDIAN_H
@@ -538,7 +538,6 @@ Audio::Level Audio::impulse(Info &info, void *buffer, unsigned samples)
 Audio::Level Audio::peak(Encoding encoding, void *buffer, unsigned samples)
 {
     Level max = 0, value;
-    unsigned long count;
     Sample *sp, mb;
     unsigned char *sv = (unsigned char *)&mb, *s1, *s2;
 
@@ -551,7 +550,6 @@ Audio::Level Audio::peak(Encoding encoding, void *buffer, unsigned samples)
         samples *= 2;
     case pcm16Mono:
     case cdaMono:
-        count = samples;
         if(__BYTE_ORDER == __LITTLE_ENDIAN) {
             sp = (Linear)buffer;
             while(samples--) {
@@ -1179,23 +1177,23 @@ void Audio::init(void)
 {
 #ifndef BUILD_STATIC
     char path[256];
-    fsys dir;
+    dir_t dir;
     const char *dp = getPluginPath();
     char filename[65];
 
     if(!dp)
         return;
 
-    fsys::open(dir, dp, fsys::ACCESS_DIRECTORY);
+    dir.open(dp);
 
-    while(is(dir) && fsys::read(dir, filename, sizeof(filename)) > 0) {
+    while(is(dir) && dir.read(filename, sizeof(filename)) > 0) {
         if(filename[0] == '.')
             continue;
 
         snprintf(path, sizeof(path), "%s/%s", dp, filename);
         fsys::load(path);
     }
-    fsys::close(dir);
+    dir.close();
 #endif
 }
 
